<?php
/**
 * Bootstrap class for the plugin
 * Plugin additional Demo Field
 *
 * @copyright Copyright (c) 2013, Jens Fiedler
 * @author Jens Fiedler
 * @author $Author$
 * @package Shopware
 * @subpackage Controllers_Frontend
 * @copyright Copyright (c) 2013, Jens Fiedler
 * @version $Id$
 */
class Shopware_Plugins_Backend_DemoField_Bootstrap extends Shopware_Components_Plugin_Bootstrap
{
 
	
	public function install()
    {
        $metaDataCache  = Shopware()->Models()->getConfiguration()->getMetadataCacheImpl();
        $metaDataCache->deleteAll();

		/*
			Attribute will be saved as "test_DemoField" in Database
			Namespace for Developer is, in this case, "test"
		*/
        Shopware()->Models()->addAttribute(
            's_articles_attributes',
            'test',
            'DemoField',
            'varchar(255)',
            true,
            NULL
        );
		
		
        $metaDataCache  = Shopware()->Models()->getConfiguration()->getMetadataCacheImpl();
        $metaDataCache->deleteAll();

        Shopware()->Models()->generateAttributeModels(
            array('s_articles_attributes')
        );

		/*
			Backend Action, used for adding the field to model and view.
		*/
        $this->subscribeEvent(
            'Enlight_Controller_Action_PostDispatch_Backend_Article',
            'postDispatchArticle'
        );
		/*
			Action fired for Article Listing.
		*/
		$this->subscribeEvent(
            'sArticles::sGetArticlesByCategory::after',
            'onCategory',
            0
        );
		/*
			Action fired for Article Details
		*/
		$this->subscribeEvent(
            'sArticles::sGetArticleById::after',
            'onArticle',
            0
        );

        return array('success' => true, 'invalidateCache' => array('backend', 'proxy'));
    }

    /**
     * Plugin uninstall method
     *
     * @return bool success
     */
    public function uninstall()
    {
	
		/*
			Uninstall Method.
			Remove all but return true; for testing purposes.
			Otherwise already stored data in database will be deleted.
		*/
		
		Shopware()->Models()->removeAttribute(
            's_articles_attributes',
            'test',
            'DemoField'
        );

        $metaDataCache  = Shopware()->Models()->getConfiguration()->getMetadataCacheImpl();
        $metaDataCache->deleteAll();

        Shopware()->Models()->generateAttributeModels(
            array('s_articles_attributes')
        );
        return true;
    }

    /**
     * @param Enlight_Event_EventArgs $args
     * @return string
     */
    public function postDispatchArticle(Enlight_Event_EventArgs $args)
    {
        $args->getSubject()->View()->addTemplateDir(
            $this->Path() . 'Views/'
        );

		/*
			Load model and view
		*/
        if ($args->getRequest()->getActionName() === 'load') {
			$args->getSubject()->View()->extendsTemplate(
                'backend/DemoField/article/model/article.js'
            );
            $args->getSubject()->View()->extendsTemplate(
                'backend/DemoField/article/view/detail/DemoField_window.js'
            );
        }
    }
	
	/*
		Query for article details
		
		Frontend Var: sArticle
		Fieldname: test_DemoField //you can pick your favorite Name
		Smarty tag for tpl: {$sArticle.test_DemoField}
	*/
	function onArticle(Enlight_Hook_HookArgs $args)
	{
		$article = $args->getReturn();
		$id = $article["articleID"];
		$sqlQuery = "SELECT test_DemoField FROM s_articles_attributes WHERE articleID=".$id." AND test_DemoField != ''";
		$article["test_DemoField"] = Shopware()->Db()->fetchOne($sqlQuery);
		$args->setReturn($article);
	}
	/*
		Query for category listing
		Frontend Var: sArticles
		Fieldname: test_DemoField //you can pick your favorite Name
		Smarty tag for tpl (frontend/listing/box_article.tpl): {$sArticle.test_DemoField}
	*/
	function onCategory(Enlight_Hook_HookArgs $args)
	{
		$articles = $args->getReturn();
		foreach ($articles['sArticles'] as $articleKey => $articleValue) {
			 
			 $id = $articles['sArticles'][$articleKey]["articleID"];
			 $sqlQuery = "SELECT test_DemoField FROM s_articles_attributes WHERE articleID=".$id." AND test_DemoField != ''";
			 $articles['sArticles'][$articleKey]["test_DemoField"] = Shopware()->Db()->fetchOne($sqlQuery);
		}
		
		$args->setReturn($articles);
	}
	
	public function getInfo()
	{
		return array(
			'version' => $this->getVersion(),
			'autor' => 'Jens Fiedler',
            'label' => $this->getLabel(),
			'source' => "Community",
			'description' => '<p style="font-size:12px; font-weight: bold;">Additional Demo Field</p>',
			'license' => '',
			'copyright' => 'Copyright  2012, jensfiedler.de',
			'support' => 'jens@jensfiedler.de',
			'link' => 'http://www.jensfiedler.de/'
		);
	}
	
	public function update($oldVersion)
	{
		return true;
	}
	
	public function getVersion()
    {
        return '1.0.0';
    }
 
    public function getLabel()
    {
        return 'Demo Field';
    }
  
    public function getCapabilities()
    {
       return array(
             'install' => true,
             'enable' => true,
             'update' => true
       );
    }
}